@@ -12,7 +12,7 @@ int32_t SPVM__Sys__IO__Utimbuf__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t error_id = 0;
   
-  struct utimbuf* st_utimbuf = env->new_memory_stack(env, stack, sizeof(struct utimbuf));
+  struct utimbuf* st_utimbuf = env->new_memory_block(env, stack, sizeof(struct utimbuf));
   
   void* obj_utimbuf = env->new_pointer_object_by_name(env, stack, "Sys::IO::Utimbuf", st_utimbuf, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
@@ -31,7 +31,7 @@ int32_t SPVM__Sys__IO__Utimbuf__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   assert(st_utimbuf);
   
-  env->free_memory_stack(env, stack, st_utimbuf);
+  env->free_memory_block(env, stack, st_utimbuf);
   env->set_pointer(env, stack, obj_utimbuf, NULL);
   
   return 0;
