@@ -12,7 +12,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t error_id = 0;
   
-  struct ip_mreq* multi_request = env->new_memory_stack(env, stack, sizeof(struct ip_mreq));
+  struct ip_mreq* multi_request = env->new_memory_block(env, stack, sizeof(struct ip_mreq));
 
   void* obj_multi_request = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Ip_mreq", multi_request, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
@@ -31,7 +31,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   assert(multi_request);
   
-  env->free_memory_stack(env, stack, multi_request);
+  env->free_memory_block(env, stack, multi_request);
   env->set_pointer(env, stack, obj_multi_request, NULL);
   
   return 0;
@@ -47,7 +47,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq__imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* sta
   
   struct in_addr address = multi_request->imr_multiaddr;
 
-  struct in_addr* address_ret = env->new_memory_stack(env, stack, sizeof(struct in_addr));
+  struct in_addr* address_ret = env->new_memory_block(env, stack, sizeof(struct in_addr));
   *address_ret = address;
 
   void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &error_id, __func__, FILE_NAME, __LINE__);
@@ -82,7 +82,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq__imr_interface(SPVM_ENV* env, SPVM_VALUE* sta
   
   struct in_addr imr_interface = multi_request->imr_interface;
 
-  struct in_addr* imr_interface_ret = env->new_memory_stack(env, stack, sizeof(struct in_addr));
+  struct in_addr* imr_interface_ret = env->new_memory_block(env, stack, sizeof(struct in_addr));
   *imr_interface_ret = imr_interface;
 
   void* obj_imr_interface_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", imr_interface_ret, &error_id, __func__, FILE_NAME, __LINE__);
