@@ -24,7 +24,7 @@ The Sys::Process class of L<SPVM> has methods to call system calls for time mani
 
 =head2 time
 
-  static method time : long ();
+C<static method time : long ();>
 
 Gets the current epoch time. 
 
@@ -34,7 +34,7 @@ This method is the same as C<time> function of C<Linux>.
 
 =head2 localtime
 
-  static method localtime : Sys::Time::Tm ($time : long);
+C<static method localtime : L<Sys::Time::Tm|SPVM::Sys::Time::Tm> ($time : long);>
 
 Converts an epoch $time to the L<Sys::Time::Tm|SPVM::Sys::Time::Tm> object that is local time.
 
@@ -44,7 +44,7 @@ This method is the same as C<localtime> function of C<Linux>.
 
 =head2 gmtime
 
-  static method gmtime : Sys::Time::Tm ($time : long);
+C<static method gmtime : L<Sys::Time::Tm|SPVM::Sys::Time::Tm> ($time : long);>
 
 Converts an epoch $time to the L<Sys::Time::Tm|SPVM::Sys::Time::Tm> object that is C<UTC>.
 
@@ -54,7 +54,7 @@ This method is the same as C<gmtime> function of C<Linux>.
 
 =head2 gettimeofday
 
-  static method gettimeofday : int ($tv : Sys::Time::Timeval, $tz : Sys::Time::Timezone);
+C<static method gettimeofday : int ($tv : L<Sys::Time::Timeval|SPVM::Sys::Time::Timeval>, $tz : L<Sys::Time::Timezone|SPVM::Sys::Time::Timezone>);>
 
 The functions gettimeofday() can get the time as well as a timezone. The tv argument is a struct timeval (as specified in <sys/time.h>):
 
@@ -62,7 +62,7 @@ See L<gettimeofday(2) - Linux man page|https://linux.die.net/man/2/gettimeofday>
 
 =head2 clock
 
-  static method clock : long ()
+C<static method clock : long ()>
 
 The value returned is the CPU time used so far as a clock_t; to get the number of seconds used, divide by CLOCKS_PER_SEC.
 
@@ -70,7 +70,7 @@ See L<clock(3) - Linux man page|https://linux.die.net/man/3/clock> in Linux.
 
 =head2 clock_gettime
 
-  static method clock_gettime : int ($clk_id : int, $tp : Sys::Time::Timespec);
+C<static method clock_gettime : int ($clk_id : int, $tp : L<Sys::Time::Timespec|SPVM::Sys::Time::Timespec>);>
 
 The functions clock_gettime() retrieves the time of the specified clock clk_id.
 
@@ -80,7 +80,7 @@ The C<$tp> is a L<Sys::Time::Timespec|SPVM::Sys::Time::Timespec> object.
 
 =head2 clock_getres
 
-  static method clock_getres : int ($clk_id : int, $res : Sys::Time::Timespec);
+C<static method clock_getres : int ($clk_id : int, $res : L<Sys::Time::Timespec|SPVM::Sys::Time::Timespec>);>
 
 The functions clock_getres() retrieves the time of the specified clock clk_id.
 
@@ -90,7 +90,7 @@ The C<$res> is a L<Sys::Time::Timespec|SPVM::Sys::Time::Timespec> object.
 
 =head2 setitimer
 
-  static method setitimer : int ($which : int, $new_value : Sys::Time::Itimerval, $old_value : Sys::Time::Itimerval)
+C<static method setitimer : int ($which : int, $new_value : L<Sys::Time::Itimerval|SPVM::Sys::Time::Itimerval>, $old_value : L<Sys::Time::Itimerval|SPVM::Sys::Time::Itimerval>)>
 
 The function setitimer() sets the specified timer to the value in new_value. If old_value is non-NULL, the old value of the timer is stored there.
 
@@ -102,7 +102,7 @@ The C<$old_value> is a L<Sys::Time::Itimerval|SPVM::Sys::Time::Itimerval> object
 
 =head2 getitimer
 
-  static method getitimer : int ($which : int, $curr_value : Sys::Time::Itimerval);
+C<static method getitimer : int ($which : int, $curr_value : L<Sys::Time::Itimerval|SPVM::Sys::Time::Itimerval>);>
 
 The function getitimer() fills the structure pointed to by curr_value with the current setting for the timer specified by which (one of ITIMER_REAL, ITIMER_VIRTUAL, or ITIMER_PROF).
 
@@ -112,7 +112,7 @@ The C<$curr_value> is a L<Sys::Time::Itimerval|SPVM::Sys::Time::Itimerval> objec
 
 =head2 times
 
-  static method times : long ($buffer : Sys::Time::Tms);
+C<static method times : long ($buffer : L<Sys::Time::Tms|SPVM::Sys::Time::Tms>);>
 
 times() stores the current process times in the struct tms that buf points to. The struct tms is as defined in <sys/times.h>:
 
@@ -120,7 +120,7 @@ See the detail of the L<times|https://linux.die.net/man/2/times> function in the
 
 =head2 clock_nanosleep
 
-  static method clock_nanosleep : int ($clockid : int, $flags : int, $request : Sys::Time::Timespec, $remain : Sys::Time::Timespec);
+C<static method clock_nanosleep : int ($clockid : int, $flags : int, $request : L<Sys::Time::Timespec|SPVM::Sys::Time::Timespec>, $remain : L<Sys::Time::Timespec|SPVM::Sys::Time::Timespec>);>
 
 Like nanosleep(2), clock_nanosleep() allows the calling thread to sleep for an interval specified with nanosecond precision. It differs in allowing the caller to select the clock against which the sleep interval is to be measured, and in allowing the sleep interval to be specified as either an absolute or a relative value.
 
@@ -132,7 +132,7 @@ The C<$remain> is a L<Sys::Time::Timespec|SPVM::Sys::Time::Timespec> object.
 
 =head2 nanosleep
 
-  static method nanosleep : int ($rqtp : Sys::Time::Timespec, $rmtp : Sys::Time::Timespec);
+C<static method nanosleep : int ($rqtp : L<Sys::Time::Timespec|SPVM::Sys::Time::Timespec>, $rmtp : L<Sys::Time::Timespec|SPVM::Sys::Time::Timespec>);>
 
 The nanosleep() function shall cause the current thread to be suspended from execution until either the time interval specified by the rqtp argument has elapsed or a signal is delivered to the calling thread, and its action is to invoke a signal-catching function or to terminate the process.
 
